@@ -1,9 +1,6 @@
 #include <iostream>
 #include <tuple>
-
 #include <string>
-
-
 using namespace std;
 
 int main()
@@ -12,7 +9,7 @@ int main()
 
     double pi = 3.14;
     tuple_idsc idsc(59, pi, "hello", "fixed");
-    tuple_idsc empty;
+//    tuple_idsc empty;     // cannot do this: no reference to double
 
     cout << tuple_size<tuple_idsc>::value << '\n';
     tuple_element<2, tuple_idsc>::type text("hi");
